@@ -57,12 +57,22 @@ def open_op(mat, iterations=1, kernel_size=3):
     mat_dilated = cv.dilate(mat_dilated.astype(np.uint8), kernel, iterations=iterations)
     return mat_dilated > 0
 
-def get_gravity_center(mask):
+def get_bool_gravity_center(mask):
     num = np.sum(np.abs(mask))
     gra_cen_x = np.sum(np.abs(mask) * np.arange(mask.shape[1]) / max(1, num))
     gra_cen_y = np.sum(np.abs(mask).T * np.arange(mask.shape[0]) / max(1, num))
     return gra_cen_x, gra_cen_y
 
+def get_gravity_center(image, mask=None):
+    image = image.astype('uint8')
+    if mask:
+        img = image[mask!=0]
+    else:
+        img = image
+    value, _ = np.histogram(img, bins=256, range=[0,256])
+    image_gravity_center = np.sum(value * np.arange(256)) / max(np.sum(value), 1)
+    return image_gravity_center
+
 def contour_center(mask):
     contours, hierarchy = cv2.findContours((mask != 0).astype('uint8'), 2, 1)
     points = np.vstack(contours).squeeze()
@@ -114,7 +124,7 @@ def image_resize(img_source, shape=None, factor=None, unique_check=False, interp
             shape = [shape] * 2
         shape = vvd_round(shape)
 
-        resized_image = cv2.resize(img_source, shape)
+        resized_image = cv2.resize(img_source, shape, interpolation=interpolation)
 
     elif factor is not None:
         if iterable(factor):
@@ -1035,13 +1045,13 @@ def get_xyxy_from_mask(mask):
 
     return [x,y,x+w,y+h]
 
-def get_polar_ring(image, center, outer_radius, inner_radius=0, factor=1):
+def get_polar_ring(image, center, outer_radius, inner_radius=0, factor=1, interpolation=12):
     size_X = vvd_round(outer_radius)
     size_Y = vvd_round(outer_radius * 2 * np.pi)
     
     dsize = [size_X, size_Y]
     center = vvd_round(center)
-    ori_polar = cv2.warpPolar(image, dsize, center, size_X, 12)
+    ori_polar = cv2.warpPolar(image, dsize, center, size_X, interpolation)
     band = ori_polar[:, vvd_round(inner_radius):, ...]
     if factor != 1:
         band = image_resize(band, factor=factor)
@@ -1077,7 +1087,7 @@ def apply_gimp_brightness_contrast(input_img, brightness = 0, contrast = 0):
 
     return buf
 
-def connected_filter(image, min_area=0, w_h_ratio=None, largest_num=None, w_min=None, w_max=None, h_min=None, h_max=None):
+def connected_filter(image, min_area=0, w_h_ratio=None, largest_num=None, w_min=None, w_max=None, h_min=None, h_max=None, final_value=1):
     image = to_gray_image(image)
     image = (image != 0).astype('uint8')
     num, mark_img, info, _ = cv2.connectedComponentsWithStats(image)
@@ -1116,7 +1126,7 @@ def connected_filter(image, min_area=0, w_h_ratio=None, largest_num=None, w_min=
                     if sub_info[3] > h_max:
                         continue
             mark_img[mark_img == index] = - index
-    res_img = (mark_img < 0).astype('uint8')
+    res_img = (mark_img < 0).astype('uint8') * final_value
     return res_img
 
 
