@@ -662,7 +662,7 @@ def draw_RG_map(y_true, y_pred, map_save_path=None):
         plt.show()
 
 
-def histgrom(*data, bin_num=100, show=True):
+def histogram(*data, bin_num=100, show=True):
     data_list = list(data)
     value, bins = np.histogram(data_list, bins=bin_num)
     for data_item in data_list:
@@ -1489,6 +1489,23 @@ def remove_file(path):
 def get_path_stem(path):
     return Path(path).stem
 
+def path_with_suffix(path, suffix):
+    if suffix[0] != '.':
+        suffix = '.' + suffix
+    return uniform_split_char(Path(path).with_suffix(suffix))
+
+def path_with_name(path, name):
+    return uniform_split_char(Path(path).with_name(name))
+
+def get_path_parent(path):
+    return uniform_split_char(Path(path).parent)
+
+def get_path_name(path):
+    return Path(path).name
+
+def strip_path_slash(path):
+    return uniform_split_char(path).strip('/')
+
 def remove_dir(path):
     """remove a dir or a symlink"""
     path = str(path)
